==> evolution-1.3.2.zip: evolution-1.3.2/manager/includes/lang/errormsg/german.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language German
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Es sind keine Fehler aufgetreten.";
$_lang["An error occured!"] = "Ein Fehler ist aufgetreten!";
$_lang["You don't have enough privileges for this action!"] = "Sie haben nicht genügend Rechte, um diese Aktion auszuführen!";
$_lang["ID passed in request is NaN!"] = "Die übergebene ID ist nicht numerisch!";
$_lang["The document is locked!"] = "Das Ressource ist gesperrt!";
$_lang["Too many results returned from database!"] = "Es wurden zu viele Ergebnisse aus der Datenbank zurückgegeben!";
$_lang["Not enough/ no results returned from database!"] = "Es wurden zu wenige/keine Ergebnisse aus der Datenbank zurückgegeben!";
$_lang["Couldn't find parent document's name!"] = "Konnte den Namen der Eltern-Ressource nicht finden!";
$_lang["Logging error!"] = "Fehler beim Protokollieren!";
$_lang["Table to optimise not found in request!"] = "Die zu optimierende Tabelle wurde nicht gefunden!";
$_lang["No settings found in request!"] = "Es wurden keine Einstellungen in der Abfrage gefunden!";
$_lang["The document must have a title!"] = "Die Ressource benötigt einen Titel!";
$_lang["No user selected as recipient of this message!"] = "Es wurde kein Benutzer als Empfänger der Nachricht ausgewählt!";
$_lang["No group selected as recipient of this message!"] = "Es wurde keine Benutzergruppe als Empfänger der Nachricht ausgewählt!";
$_lang["The document was not found!"] = "Die Ressource wurde nicht gefunden!";
$_lang["Double action (GET & POST) posted!"] = "Doppelte Aktion (GET & POST) angeben!";
$_lang["Document cannot be it's own parent!"] = "Eine Ressource kann nicht ihre eigene Elternressource sein!";
$_lang["Document's ID not passed in request!"] = "Es wurde keine Ressourcen ID in der Abfrage angegeben!";
$_lang["New parent not set in request!"] = "Es wurde keine Elternressource in der Abfrage angegeben!";
$_lang["don't know the user!" ] = "Benutzername oder Passwort falsch eingegeben!";
$_lang["wrong password!"] = "Benutzername oder Passwort falsch eingegeben!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Aufgrund von zu vielen fehlerhaften Anmeldeversuchen wurden Sie gesperrt!";
$_lang["You are blocked and cannot log in!"] = "Sie wurden gesperrt und können sich nicht anmelden!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Sie wurden gesperrt und können sich nicht anmelden! Probieren Sie es später noch einmal!";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "Der Sicherheitscode stimmt nicht überein! Bitte loggen Sie sich erneut ein!";

==> evolution-1.4.26.zip: evolution-1.4.26/manager/includes/lang/errormsg/german.inc.php <==
<?php
/**
 * MODX error messages language file
 *
 * @version 1.0.13
 * @date 31/12/2013
 *
 * @language German
 * @package modx
 * @subpackage manager
 *
 * Please commit your language changes on Transifex (https://www.transifex.com/projects/p/modx-evolution/) or on GitHub (https://github.com/modxcms/evolution).
 */
$_lang["No errors occured."] = "Es sind keine Fehler aufgetreten.";
$_lang["An error occured!"] = "Ein Fehler ist aufgetreten!";
$_lang["You don't have enough privileges for this action!"] = "Sie haben nicht genügend Rechte, um diese Aktion auszuführen!";
$_lang["ID passed in request is NaN!"] = "Die übergebene ID ist nicht numerisch!";
$_lang["The document is locked!"] = "Das Ressource ist gesperrt!";
$_lang["Too many results returned from database!"] = "Es wurden zu viele Ergebnisse aus der Datenbank zurückgegeben!";
$_lang["Not enough/ no results returned from database!"] = "Es wurden zu wenige/keine Ergebnisse aus der Datenbank zurückgegeben!";
$_lang["Couldn't find parent document's name!"] = "Konnte den Namen der Eltern-Ressource nicht finden!";
$_lang["Logging error!"] = "Fehler beim Protokollieren!";
$_lang["Table to optimise not found in request!"] = "Die zu optimierende Tabelle wurde nicht gefunden!";
$_lang["No settings found in request!"] = "Es wurden keine Einstellungen in der Abfrage gefunden!";
$_lang["The document must have a title!"] = "Die Ressource benötigt einen Titel!";
$_lang["No user selected as recipient of this message!"] = "Es wurde kein Benutzer als Empfänger der Nachricht ausgewählt!";
$_lang["No group selected as recipient of this message!"] = "Es wurde keine Benutzergruppe als Empfänger der Nachricht ausgewählt!";
$_lang["The document was not found!"] = "Die Ressource wurde nicht gefunden!";
$_lang["Double action (GET & POST) posted!"] = "Doppelte Aktion (GET & POST) angeben!";
$_lang["Document cannot be it's own parent!"] = "Eine Ressource kann nicht ihre eigene Elternressource sein!";
$_lang["Document's ID not passed in request!"] = "Es wurde keine Ressourcen ID in der Abfrage angegeben!";
$_lang["New parent not set in request!"] = "Es wurde keine Elternressource in der Abfrage angegeben!";
$_lang["don't know the user!" ] = "Falscher Benutzername oder Passwort eingegeben oder Sie wurden gesperrt!";
$_lang["wrong password!"] = "Falscher Benutzername oder Passwort eingegeben oder Sie wurden gesperrt!";
$_lang["Due to too many failed logins, you have been blocked!"] = "Falscher Benutzername oder Passwort eingegeben oder Sie wurden gesperrt!";
$_lang["You are blocked and cannot log in!"] = "Falscher Benutzername oder Passwort eingegeben oder Sie wurden gesperrt!";
$_lang["You are blocked and cannot log in! Please try again later."] = "Falscher Benutzername oder Passwort eingegeben oder Sie wurden gesperrt!";
$_lang["The security code you entered didn't validate! Please try to login again!"] = "Der Sicherheitscode stimmt nicht überein! Bitte loggen Sie sich erneut ein!";
